VPSPulse Mirrors

High-Performance Open-Source Archive

Help for package SubVis

Package {SubVis}


Version: 2.0.2
Date: 2017-05-08
Title: Visual Exploration of Protein Alignments Resulting from Multiple Substitution Matrices
Description: Substitution matrices are important parameters in protein alignment algorithms. These matrices represent the likelihood that an amino acid will be substituted for another during mutation. This tool allows users to apply predefined and custom matrices and then explore the resulting alignments with interactive visualizations. 'SubVis' requires the availability of a web browser.
Depends: R (≥ 3.3.0), shiny, Biostrings
License: GPL-3
Author: Scott Barlowe <sabarlowe@email.wcu.edu>
Maintainer: Scott Barlowe <sabarlowe@email.wcu.edu>
RoxygenNote: 5.0.1
Suggests: knitr, rmarkdown
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2017-05-08 14:28:33 UTC; sabarlowe
Repository: CRAN
Date/Publication: 2017-05-23 03:44:06 UTC

Starts the SubVis app

Description

Author: Scott Barlowe Date: June 15, 2016

Usage

startSubVis()

Examples



startSubVis()


Need mirroring services?
Contact our team at info@vpspulse.com.

Mirror powered by VPSpulse

Infrastructure sponsored by VPSPulse & Secure Payments by ArionPay.